@@ -25,10 +25,10 @@ Enables identical use for installed and uninstalled versions.
 
 import os.path
 
-LIBDIR = '/usr/lib'
-PKGDATADIR = '/usr/share/pitivi'
-PIXMAPDIR = '/usr/share/pixmaps'
-pitivi_version = '0.13.1.3'
+LIBDIR = '/usr/local/lib'
+PKGDATADIR = '/usr/local/share/pitivi'
+PIXMAPDIR = '/usr/local/share/pixmaps'
+pitivi_version = '0.13.2'
 APPNAME = 'PiTiVi'
 PYGTK_REQ = '2.14.0'
 PYGST_REQ = '0.10.16'
