@@ -52,6 +52,10 @@ class Controller(object):
     _initial = None
     _mousedown = None
     _last_event = None
+    _pending_drag_start = None
+    _pending_drag_end = False
+    _shift_down = False
+    _control_down = False
 
     def __init__(self, view=None):
         object.__init__(self)
@@ -91,9 +95,9 @@ class Controller(object):
         self._event_common(item, target, event)
         self._canvas.keyboard_ungrab(item, event.time)
         self._ptr_within = False
-        event.window.set_cursor(ARROW)
         if not self._dragging:
             self.leave(item, target)
+            event.window.set_cursor(ARROW)
         return True
 
     @handler(_view, "button_press_event")
@@ -105,13 +109,19 @@ class Controller(object):
             item, event))
         self._dragging = target
         self._initial = self.pos(target)
-        self._drag_start(item, target, event)
+        self._pending_drag_start = (item, target, event)
         return True
 
     @handler(_view, "motion_notify_event")
     def motion_notify_event(self, item, target, event):
         self._event_common(item, target, event)
         if self._dragging:
+            if self._pending_drag_start is not None:
+                pending_drag_start, self._pending_drag_start = \
+                        self._pending_drag_start, None
+                self._pending_drag_end = True
+                self._drag_start(*pending_drag_start)
+
             self.set_pos(self._dragging,
                 self.transform(self._mousedown + self.from_item_event(item,
                     event)))
@@ -125,18 +135,45 @@ class Controller(object):
         self._dragging = None
         return True
 
+    @handler(_view, "key_press_event")
+    def key_press_event(self, item, target, event):
+        self._event_common(item, target, event)
+        kv = event.keyval
+        if kv in (gtk.keysyms.Shift_L, gtk.keysyms.Shift_R):
+            self._shift_down = True
+        elif kv in (gtk.keysyms.Control_L, gtk.keysyms.Control_R):
+            self._control_down = True
+        return self.key_press(kv)
+
+    @handler(_view, "key_release_event")
+    def key_release_event(self, item, target, event):
+        self._event_common(item, target, event)
+        kv = event.keyval
+        if kv in (gtk.keysyms.Shift_L, gtk.keysyms.Shift_R):
+            self._shift_down = False
+        elif kv in (gtk.keysyms.Control_L, gtk.keysyms.Control_R):
+            self._control_down = False
+        return self.key_release(kv)
+
 ## internal callbacks
 
     def _event_common(self, item, target, event):
         if not self._canvas:
             self._canvas = item.get_canvas()
         self._last_event = event
+        s = event.get_state()
+        self._shift_down = s & gtk.gdk.SHIFT_MASK
+        self._control_down = s & gtk.gdk.CONTROL_MASK
 
     def _drag_start(self, item, target, event):
-        self.drag_start()
+        self.drag_start(item, target, event)
 
     def _drag_end(self, item, target, event):
-        self.drag_end()
+        self._pending_drag_start = None
+        pending_drag_end, self._pending_drag_end = self._pending_drag_end, False
+        if pending_drag_end:
+            self.drag_end(item, target, event)
+
         if self._ptr_within and self._drag_threshold():
             point = self.from_item_event(item, event)
             if self._last_click and (event.time - self._last_click < 400):
@@ -144,6 +181,9 @@ class Controller(object):
             else:
                 self.click(point)
             self._last_click = event.time
+            event.window.set_cursor(self._cursor)
+        else:
+            event.window.set_cursor(ARROW)
 
     def _drag_threshold(self):
         last = self.pos(self._dragging)
@@ -160,10 +200,10 @@ class Controller(object):
     def double_click(self, pos):
         pass
 
-    def drag_start(self):
+    def drag_start(self, item, target, event):
         pass
 
-    def drag_end(self):
+    def drag_end(self, item, target, event):
         pass
 
     def set_pos(self, obj, pos):
@@ -177,3 +217,9 @@ class Controller(object):
 
     def leave(self, item, target):
         pass
+
+    def key_press(self, keyval):
+        pass
+
+    def key_release(self, keyval):
+        pass
